import type { Express } from "express";
import { createServer, type Server } from "http";
import { storage } from "./storage";
import path from "path";
import express from "express";

export async function registerRoutes(app: Express): Promise<Server> {
  // put application routes here
  // prefix all routes with /api

  // use storage to perform CRUD operations on the storage interface
  // e.g. storage.insertUser(user) or storage.getUserByUsername(username)

  // Serve static HTML files from the root directory
  app.use(express.static(path.join(process.cwd())));

  // Serve specific HTML files based on routes
  app.get('/', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'index.html'));
  });

  app.get('/products', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'products.html'));
  });

  app.get('/product/:id', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'product.html'));
  });

  app.get('/cart', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'cart.html'));
  });

  app.get('/checkout', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'checkout.html'));
  });

  app.get('/login', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'login.html'));
  });

  app.get('/signup', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'signup.html'));
  });

  app.get('/user', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'user.html'));
  });

  app.get('/about', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'about.html'));
  });

  app.get('/contact', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'contact.html'));
  });

  app.get('/support', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'support.html'));
  });

  // Handle 404 errors - serve 404.html
  app.use((req, res) => {
    res.status(404).sendFile(path.join(process.cwd(), '404.html'));
  });

  const httpServer = createServer(app);

  return httpServer;
}
